@@ -975,7 +975,7 @@ class EcotouchTag(TagData, Enum):  # pylint: disable=function-redefined
     TEMPERATURE_COOLING_RETURN = TagData(["A33"], "°C")
     TEMPERATURE_COOLING_SET = TagData(["A34"], "°C")
     TEMPERATURE_COOLING_SET2 = TagData(["A35"], "°C")
-    TEMPERATURE_WATER_SETPOINT = TagData(["A37"], "°C", writeable=True)
+    TEMPERATURE_WATER_SETPOINT = TagData(["A37"], "°C")
     TEMPERATURE_WATER_SETPOINT2 = TagData(["A38"], "°C", writeable=True)
     TEMPERATURE_POOL_SETPOINT = TagData(["A40"], "°C", writeable=True)
     TEMPERATURE_POOL_SETPOINT2 = TagData(["A41"], "°C", writeable=True)
@@ -992,7 +992,7 @@ class EcotouchTag(TagData, Enum):  # pylint: disable=function-redefined
     MAX_VL_TEMP = TagData(["A95"], "°C")
     TEMP_SET_0_DEG = TagData(["A97"], "°C")
     COOL_ENABLE_TEMP = TagData(["A108"], "°C")
-    NVI_SOLL_KUEHLEN = TagData(["A109"], "°C")
+    NVI_SOLL_KUEHLEN = TagData(["A109"], "°C", writeable=True)
     TEMPCHANGE_HEATING_PV = TagData(["A682"], "°C")
     TEMPCHANGE_COOLING_PV = TagData(["A683"], "°C")
     TEMPCHANGE_WARMWATER_PV = TagData(["A684"], "°C")
